@@ -16,7 +16,6 @@ const char *ripe_servers[] = {
     "whois.nic.fr",
     "whois.nic.it",
     "whois.telstra.net",
-    "whois.nic.net.sg",
     "whois.metu.edu.tr",
     "whois.restena.lu",
     "rr.level3.net",		/* 3.0.0a13 */
@@ -25,14 +24,7 @@ const char *ripe_servers[] = {
     "www.registry.co.ug",
     "whois.nic.ir",
     "whois.nic.ck",
-    NULL
-};
-
-/* servers which do not accept the new syntax */
-const char *ripe_servers_old[] = {
     "whois.ra.net",
-    "whois.domain.kg",
-    "whois.nic.ch",
     NULL
 };
 
@@ -48,7 +40,6 @@ const char *hide_strings[] = {
     "This whois service currently only", "top-level domains.",
     "Signature Domains' Whois Service", "agree to abide by the above",
     "Access to ASNIC", "by this policy.",			/* as */
-    "**************", "**************",				/* sg */
     "The Data in Gabia", "you agree to abide",
     "The data contained in Go Daddy", "is not the registrant",	/* Go Daddy */
     "Disclaimer: The Global Name Registry", "for any commercial",
@@ -59,11 +50,14 @@ const char *hide_strings[] = {
     // This must be disabled because whois.bizcn.com uses a similar text
     "The data in this whois", "using our Whois information",	/* enom */
 #endif
-    "By submitting a WHOIS query,", "LACK OF A DOMAIN",		/* directNIC */
+    "By submitting a WHOIS query, you agree you will", "LACK OF A DOMAIN",		/* directNIC */
+    "The Data in Moniker.com", "this query, you agree",
     "The Data in OnlineNIC", "    By starting this query",	/* OnlineNIC */
     "The data in Bulkregister.com", "you agree to abide", /* bulkregister */
     "The Data in Alldomains.com's", "By submitting this query,",/*alldomains*/
     "Interdomain's WHOIS", "DOES NOT SIGNIFY",
+    "The Data provided by Stargate.com", "(2) enable any",
+    "; This data is provided by dd24", "; By submitting this query",
     NULL, NULL
 };
 
@@ -151,6 +145,9 @@ const struct ip6_del ip6_assign_misc[] = {
     { 0x44, "whois.apnic.net" },
     { 0x46, "whois.ripe.net" },
     { 0x48, "whois.arin.net" },
+    { 0x4A, "whois.ripe.net" },
+    { 0x4C, "whois.ripe.net" },
+    { 0x4E, "whois.ripe.net" }, /* not yet allocated, but... */
     { 0x50, "whois.ripe.net" },
     { 0x52, "whois.ripe.net" },
     { 0x54, "whois.ripe.net" },
@@ -159,6 +156,31 @@ const struct ip6_del ip6_assign_misc[] = {
     { 0x5A, "whois.ripe.net" },
     { 0x5C, "whois.ripe.net" },
     { 0x5E, "whois.ripe.net" },
+
+    { 0x80, "whois.apnic.net" },
+    { 0x82, "whois.apnic.net" },
+    { 0x84, "whois.apnic.net" },
+    { 0x86, "whois.apnic.net" },
+    { 0x88, "whois.apnic.net" },
+    { 0x8A, "whois.apnic.net" },
+    { 0x8C, "whois.apnic.net" },
+    { 0x8E, "whois.apnic.net" },
+    { 0x90, "whois.apnic.net" },
+    { 0x92, "whois.apnic.net" },
+    { 0x94, "whois.apnic.net" },
+    { 0x96, "whois.apnic.net" },
+    { 0x98, "whois.apnic.net" },
+    { 0x9A, "whois.apnic.net" },
+    { 0x9C, "whois.apnic.net" },
+    { 0x9E, "whois.apnic.net" },
+    { 0xA0, "whois.apnic.net" },
+    { 0xA2, "whois.apnic.net" },
+    { 0xA4, "whois.apnic.net" },
+    { 0xA6, "whois.apnic.net" },
+    { 0xA8, "whois.apnic.net" },
+    { 0xAA, "whois.apnic.net" },
+    { 0xAC, "whois.apnic.net" },
+    { 0xAE, "whois.apnic.net" },
     { 0, NULL }
 };
 
